#include <Event.h>
#include <Timer.h>
#include <OneWire.h> 

int DS18S20_Pin = 9;
OneWire ds(DS18S20_Pin); // on digital pin 2

byte digit0 = 10;
byte digit1 = 11;
int led = 13;

int xyz = 0;
float cTemp = 0;
int nnn = 0;
int fTemp = 0;
int oldTemp = 0;
int newTemp = 0;

Timer tmr;

byte sevenSegmentPins[] = {
  2,3,4,5,6,7,8};
byte sevenSegment[10][7] = {
  //a b c d e f g
  {     
    0,0,0,0,0,0,1         }  
  ,  // = 0
  {     
    1,0,0,1,1,1,1         }  
  ,  // = 1
  {     
    0,0,1,0,0,1,0         }  
  ,  // = 2
  {     
    0,0,0,0,1,1,0         }  
  ,  // = 3
  {     
    1,0,0,1,1,0,0         }  
  ,  // = 4
  {     
    0,1,0,0,1,0,0         }  
  ,  // = 5
  {     
    0,1,0,0,0,0,0         }  
  ,  // = 6
  {     
    0,0,0,1,1,1,1         }  
  ,  // = 7
  {     
    0,0,0,0,0,0,0         }  
  ,  // = 8
  {     
    0,0,0,1,1,0,0         }   // = 9
};

void setup()
{
  pinMode(digit0, OUTPUT); //pin 10
  pinMode(digit1, OUTPUT); //pin 11
  pinMode(led, OUTPUT); //pin 13

  for(int i=0; i<7; i++)
  {
    pinMode(sevenSegmentPins[i], OUTPUT);
  }
  digitalWrite(digit0, HIGH);
  digitalWrite(digit1, HIGH);
  digitalWrite(led, LOW);     

  //get initial temp
  calledEvery10secs();

  //then get temp every 10 seconds therafter
  tmr.every(10000, calledEvery10secs);

}

void segmentWrite(byte digit)
{
  byte pin = 2;
  for (byte i=0; i<7; ++i)
  {
    digitalWrite(pin, sevenSegment[digit][i]);
    ++pin;
  }
  Serial.println(digit);
}

void loop() {

  tmr.update();

  //the sketch starts with 'oldTemp' being equal to zero, so the first 'newTemp' reading will automatically 
  //be passed into 'oldTemp'
  //compare temps, only display the new temp reading if it differs from the last temp measurement  
  if (newTemp == oldTemp) {
    //display oldTemp
    nnn = oldTemp*100;
  }
  else {
    nnn = newTemp*100;
  }

  //handle invalid temps
  if ((nnn < 1) || (nnn > 9900)) {
    //display zeroes
    nnn = 0;
  }

  //display temp
  showNum(nnn);
}

void calledEvery10secs() {

  cTemp = getTemp();

  //convert Celcius to Fahrenheit
  fTemp = (cTemp * 1.8) + 32.0; 

  //sensor seems to run about 2 degrees hotter...compensate here
  fTemp = fTemp - 2;

  //pass temp into variable for comparison later
  newTemp = fTemp;
}

void showNum(int n) {

  //display digit 1
  int n1 = (n%10000)/1000;

  //digit 2
  int n2 = (n%1000)/100;

  //multiplex
  digitalWrite(digit0, LOW);   //enable digit0
  segmentWrite(n2);             //send number to the segments
  delay(6);                  // delay (refresh)
  digitalWrite(digit0, HIGH);  //disable digit0
  digitalWrite(digit1, LOW);   //enable digit1
  segmentWrite(n1);             //send number to the segments
  delay(6);                  // delay (refresh)
  digitalWrite(digit1, HIGH);  //disable digit1
}

////////////////////////////////////////////////////////
float getTemp(){

  byte data[12];
  byte addr[8];

  if ( !ds.search(addr)) {
    //no more sensors on chain, reset search
    ds.reset_search();
    return -1000;
  }

  if ( OneWire::crc8( addr, 7) != addr[7]) {
    Serial.println("CRC is not valid!");
    return -1000;
  }

  if ( addr[0] != 0x10 && addr[0] != 0x28) {
    Serial.print("Device is not recognized");
    return -1000;
  }

  ds.reset();
  ds.select(addr);
  ds.write(0x44,1); // start conversion, with parasite power on at the end

  byte present = ds.reset();
  ds.select(addr);  
  ds.write(0xBE); // Read Scratchpad

  for (int i = 0; i < 9; i++) { // we need 9 bytes
    data[i] = ds.read();
  }

  ds.reset_search();

  byte MSB = data[1];
  byte LSB = data[0];

  float tempRead = ((MSB << 8) | LSB); //using two's compliment
  float TemperatureSum = tempRead / 16;

  return TemperatureSum;
}




